@@ -3,6 +3,7 @@
 import asyncio
 import os
 import re
+import socket
 import sys
 from lintian_brush import USER_AGENT, DEFAULT_URLLIB_TIMEOUT
 from lintian_brush.control import update_control
@@ -87,6 +88,8 @@ def find_new_urls(vcs_type, vcs_url, package, maintainer_email,
                 timeout=DEFAULT_URLLIB_TIMEOUT)
         except urllib.error.HTTPError:
             pass
+        except socket.timeout:
+            pass
         else:
             redirected_url = response.geturl()
             if not is_on_obsolete_host(redirected_url):
